//
//  ViewController.swift
//  DownloaderDemo
//
//

import PRESTOPlay
import CastlabsApple
import CastlabsDownloader
import AVFoundation
import UIKit

let streamUrl = "https://demo.cf.castlabs.com/media/prestohls/master.m3u8"

class ViewController: UIViewController, DownloadDelegate {
    // create player instance
    var player = PRESTOPlaySDK.shared.player()
    var downloader: DownloaderAPI?

    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view.
        // optional: ignore silent switch
        try? AVAudioSession.sharedInstance().setCategory(.playback)

        guard let contentURL = URL(string: streamUrl) else { return }
        downloader = PRESTOPlaySDK.shared.downloader()
        let alreadyDownloaded = downloader?.getDownloads().contains {
            $0.playerConfiguration.contentUrl == contentURL
        } ?? false

        if alreadyDownloaded {
            print("The stream is already downloaded")
            play()
        } else {
            print("Starting the stream download")
            download()
        }
    }

    override func viewWillTransition(to size: CGSize,
                                     with coordinator: UIViewControllerTransitionCoordinator) {
        player.update(size: size)
    }

    func download() {
        guard let contentURL = URL(string: streamUrl) else { return }
        let config = PlayerConfiguration(with: contentURL)

        guard let download = downloader?.createDownload(config, headers: [:]) else { return }
        downloader?.prepareDownload(download.uuid, completion: { download, error in
            if let error = error {
                print("Error:", error.message ?? "")
                return
            }

            guard let id = download?.uuid else { return }
            if let startError = self.downloader?.startDownload(id, delegate: self) {
                print("Error:", startError.message ?? "")
            }
        })
    }

    func didStateChange(_ download: Download) {
        if download.state == .success {
            play()
        }
    }

    func didProgressChange(_ download: Download) {
        print("Progress: \(download.progress.percent)")
    }

    func play() {
        guard let contentURL = URL(string: streamUrl) else { return }
        let localDownload = downloader?.getDownloads().first { download in
            contentURL == download.playerConfiguration.contentUrl
        }
        guard let download = localDownload else { return }
        let config = try! PlayerConfiguration(with: download)

        player.load(config: config)
        player.onState = { previous, state in
            if let error = state.playerError {
                print("Error \(error)")
                return
            }
        }

        player.attach(to: view.layer)
        player.open(autoplay: true)
    }
}
