//
//  HLSPlaylistDownloader.h
//  CastlabsApple
//
//  Created by Guido Parente on 30/09/2020.
//  Copyright © 2020 com.castlabs. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

typedef NS_ENUM(NSUInteger, PlaylistDownloaderError) {
    networkError = 1,
    invalidPlaylist = 2,
    none = 100
};

@interface HLSStreamQuality: NSObject

/**
 * Corresponds to the AVERAGE-BANDWIDTH attribute off the #EXT-X-STREAM-INF Master playlist tag
 * It represents the average segment bit rate of the Variant Stream.
 */
@property (nonatomic) int64_t averageBitrate;

/**
 * Corresponds to the BANDWIDTH attribute if the #EXT-X-STREAM-INF Master playlist tag
 */
@property (nonatomic) int64_t bitrate;

/** Resolution width */
@property (nonatomic) int64_t resolutionWidth;

/** Resolution height */
@property (nonatomic) int64_t resolutionHeight;

@end

@interface HLSPlaylist : NSObject

@property NSArray<HLSStreamQuality *> * qualities;
@property NSArray<NSString *> * keyIds;

@end



@interface HLSPlaylistDownloader : NSObject

+ (void)getPlaylist:(NSURL *)url
      completion:(void (^)(HLSPlaylist*, PlaylistDownloaderError))handler;

@end

NS_ASSUME_NONNULL_END
